package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseSpecialdeviceParam;
import com.hw.dms.service.IDmsBaseSpecialdeviceParamService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 特种设备参数信息Controller
 * 
 * @author xins
 * @date 2024-01-09
 */
@RestController
@RequestMapping("/specialDeviceParam")
public class DmsBaseSpecialdeviceParamController extends BaseController
{
    @Autowired
    private IDmsBaseSpecialdeviceParamService dmsBaseSpecialdeviceParamService;

    /**
     * 查询特种设备参数信息列表
     */
    @RequiresPermissions("dms:specialDeviceParam:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam)
    {
        startPage();
        List<DmsBaseSpecialdeviceParam> list = dmsBaseSpecialdeviceParamService.selectDmsBaseSpecialdeviceParamList(dmsBaseSpecialdeviceParam);
        return getDataTable(list);
    }

    /**
     * 导出特种设备参数信息列表
     */
    @RequiresPermissions("dms:specialDeviceParam:export")
    @Log(title = "特种设备参数信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam)
    {
        List<DmsBaseSpecialdeviceParam> list = dmsBaseSpecialdeviceParamService.selectDmsBaseSpecialdeviceParamList(dmsBaseSpecialdeviceParam);
        ExcelUtil<DmsBaseSpecialdeviceParam> util = new ExcelUtil<DmsBaseSpecialdeviceParam>(DmsBaseSpecialdeviceParam.class);
        util.exportExcel(response, list, "特种设备参数信息数据");
    }

    /**
     * 获取特种设备参数信息详细信息
     */
    @RequiresPermissions("dms:specialDeviceParam:query")
    @GetMapping(value = "/{specialdeviceParamId}")
    public AjaxResult getInfo(@PathVariable("specialdeviceParamId") Long specialdeviceParamId)
    {
        return success(dmsBaseSpecialdeviceParamService.selectDmsBaseSpecialdeviceParamBySpecialdeviceParamId(specialdeviceParamId));
    }

    /**
     * 新增特种设备参数信息
     */
    @RequiresPermissions("dms:specialDeviceParam:add")
    @Log(title = "特种设备参数信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam)
    {
        return toAjax(dmsBaseSpecialdeviceParamService.insertDmsBaseSpecialdeviceParam(dmsBaseSpecialdeviceParam));
    }

    /**
     * 修改特种设备参数信息
     */
    @RequiresPermissions("dms:specialDeviceParam:edit")
    @Log(title = "特种设备参数信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam)
    {
        return toAjax(dmsBaseSpecialdeviceParamService.updateDmsBaseSpecialdeviceParam(dmsBaseSpecialdeviceParam));
    }

    /**
     * 删除特种设备参数信息
     */
    @RequiresPermissions("dms:specialDeviceParam:remove")
    @Log(title = "特种设备参数信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{specialdeviceParamIds}")
    public AjaxResult remove(@PathVariable Long[] specialdeviceParamIds)
    {
        return toAjax(dmsBaseSpecialdeviceParamService.deleteDmsBaseSpecialdeviceParamBySpecialdeviceParamIds(specialdeviceParamIds));
    }
}
